@@ -1,5 +1,5 @@
 #include <sys/types.h>
-#include <event.h>
+#include <musepack/musepack.h>
 
 int main (int argc, char **argv) {
     return 0;
